# OZI.build CHANGELOG
## 1.9.2 (2024-12-30)


### Unknown


* Update pyproject.toml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`3a35f63`](https://github.com/OZI-Project/OZI.build/commit/3a35f63b8f5a452acdc5d4155038502248591ef5))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`bea8cc1`](https://github.com/OZI-Project/OZI.build/commit/bea8cc1f44b9d70a841f5f015959dc76dbc778b7))

## 1.9.1 (2024-12-29)


### Unknown


* Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`4a8883b`](https://github.com/OZI-Project/OZI.build/commit/4a8883bd8a2333f0abce111ae413e884bcac345c))

* Bump jinja2 in /doc in the pip group across 1 directory

Bumps the pip group with 1 update in the /doc directory: [jinja2](https://github.com/pallets/jinja).


Updates `jinja2` from 3.1.4 to 3.1.5
- [Release notes](https://github.com/pallets/jinja/releases)
- [Changelog](https://github.com/pallets/jinja/blob/main/CHANGES.rst)
- [Commits](https://github.com/pallets/jinja/compare/3.1.4...3.1.5)


updated-dependencies:
- dependency-name: jinja2
  dependency-type: direct:production
  dependency-group: pip
... — dependabot[bot] <support@github.com>
([`bfb743e`](https://github.com/OZI-Project/OZI.build/commit/bfb743ec54e6bf409d73c053b01ec48e259e9b6f))

* Update index.md — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`73614d8`](https://github.com/OZI-Project/OZI.build/commit/73614d889be65a894477cded2dca56da8c6c8b93))

## 1.9.0 (2024-12-27)


### Build system


* build: fix workflow — rjdbcm <rjdbcm@outlook.com>
([`877ca93`](https://github.com/OZI-Project/OZI.build/commit/877ca937ce8481634d35940b9936690ad52d89df))

* build: fix file permissions — rjdbcm <rjdbcm@outlook.com>
([`107a6ed`](https://github.com/OZI-Project/OZI.build/commit/107a6ed2e92f4630e450c9ffcedbb95698baa409))

* build: add .mypy_cache to .gitignore — rjdbcm <rjdbcm@outlook.com>
([`e418e77`](https://github.com/OZI-Project/OZI.build/commit/e418e77dc8937d68624e725f889c2ed0b732b4bb))

* build: fix release workflow — rjdbcm <rjdbcm@outlook.com>
([`3b4a58e`](https://github.com/OZI-Project/OZI.build/commit/3b4a58e2ecf7d8fb8685c92d514d44c47acb07c9))

* build: shorter custom workflow — rjdbcm <rjdbcm@outlook.com>
([`cd8fd46`](https://github.com/OZI-Project/OZI.build/commit/cd8fd46c9fc5d7eec73ab127fd7bd1cd3586afe7))

* build: correct artifact name — rjdbcm <rjdbcm@outlook.com>
([`731e5fd`](https://github.com/OZI-Project/OZI.build/commit/731e5fd345a231c1b82df5bcb4430fc418cc0fe7))

* build: use a custom workflow — rjdbcm <rjdbcm@outlook.com>
([`0167fd2`](https://github.com/OZI-Project/OZI.build/commit/0167fd20891af2b51b5966aa017e39a2e38c050e))

* build: correct name — rjdbcm <rjdbcm@outlook.com>
([`c20e4b2`](https://github.com/OZI-Project/OZI.build/commit/c20e4b215100fc362665c69428b7a0f744b65da4))

* build: fix changelog — rjdbcm <rjdbcm@outlook.com>
([`950537f`](https://github.com/OZI-Project/OZI.build/commit/950537f1cebfb52f3fafd5b21b9cb274fb604f56))

* build: remove master release branch pattern — rjdbcm <rjdbcm@outlook.com>
([`f96d21a`](https://github.com/OZI-Project/OZI.build/commit/f96d21af1b5fecfc121490f5c2b7d06374e6a932))

* build: dont compile to bytecode — rjdbcm <rjdbcm@outlook.com>
([`ab98233`](https://github.com/OZI-Project/OZI.build/commit/ab982330db5831a7ceca55f2d50f99ebab137d54))

* build: fix some docs typos — rjdbcm <rjdbcm@outlook.com>
([`57b482a`](https://github.com/OZI-Project/OZI.build/commit/57b482adc4ea9ae9d5e05f8c4e2217cb8893be6b))

* build: fix docs title — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`7f45cdb`](https://github.com/OZI-Project/OZI.build/commit/7f45cdb42c18c074055db20d2d0b81a5c8641c97))

* build: simplify docs — rjdbcm <rjdbcm@outlook.com>
([`fb34282`](https://github.com/OZI-Project/OZI.build/commit/fb342821c09a3c4534383be5182e983d5847c188))

* build: fix docs — rjdbcm <rjdbcm@outlook.com>
([`55d4358`](https://github.com/OZI-Project/OZI.build/commit/55d4358860f19250a4603ca001a25a669c3b79bd))

* build: add doc dependency — rjdbcm <rjdbcm@outlook.com>
([`d1e038a`](https://github.com/OZI-Project/OZI.build/commit/d1e038a75d78a0f5c6677c69e01bd4c6588f1116))

* build: add sphinx docs — rjdbcm <rjdbcm@outlook.com>
([`95994db`](https://github.com/OZI-Project/OZI.build/commit/95994db49582d61e2201ddec1b88da5a0962fedf))

* build: add release branches to workflow — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`39e1d7e`](https://github.com/OZI-Project/OZI.build/commit/39e1d7e810401d856db8f7d6376a01854bbc2826))

* build: fix dist checkpoint — rjdbcm <rjdbcm@outlook.com>
([`4dd9149`](https://github.com/OZI-Project/OZI.build/commit/4dd91499c3f354e25c99f9ccaa5e38da1936f945))

* build: fix wheel release — rjdbcm <rjdbcm@outlook.com>
([`eb02a41`](https://github.com/OZI-Project/OZI.build/commit/eb02a41c4c914b6007df54323c0dec2e783ed865))

* build: skip dist checkpoint — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`6a3a5e2`](https://github.com/OZI-Project/OZI.build/commit/6a3a5e2736587dabfd7fbe581881a7253a4c3d23))

* build: no tests for now — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`00af619`](https://github.com/OZI-Project/OZI.build/commit/00af619cfd2d33026531e2dd0085560356e6bd5b))

* build: main is a release branch — rjdbcm <rjdbcm@outlook.com>
([`9c2f19b`](https://github.com/OZI-Project/OZI.build/commit/9c2f19b9ad85cc63bcbdb01ee1ef3c71838e6908))

* build: use trusted publishing and dogfood OZI — rjdbcm <rjdbcm@outlook.com>
([`4268b0d`](https://github.com/OZI-Project/OZI.build/commit/4268b0db89ebbc1c2609c66a7ab93f8f0f069a10))

* build: run black — rjdbcm <rjdbcm@outlook.com>
([`153735b`](https://github.com/OZI-Project/OZI.build/commit/153735b18c4f6a3a9419a7555009980c35bb0bdc))

* build: run isort — rjdbcm <rjdbcm@outlook.com>
([`0fb8ecf`](https://github.com/OZI-Project/OZI.build/commit/0fb8ecf36e1025822d661deb60c816888ec36f1f))


### Documentation


* docs: enable colon fence — rjdbcm <rjdbcm@outlook.com>
([`3c3230a`](https://github.com/OZI-Project/OZI.build/commit/3c3230a4ebc1cd4276857d74dd263185468a0010))

* docs: use howto pdf theme — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`0e97756`](https://github.com/OZI-Project/OZI.build/commit/0e977563b305c1011896f1b2bceb32cf4115c997))

* docs: add changelog template — rjdbcm <rjdbcm@outlook.com>
([`2851d92`](https://github.com/OZI-Project/OZI.build/commit/2851d9259a629107498c705391d01a8796623064))

* docs: add changes and docs link — rjdbcm <rjdbcm@outlook.com>
([`fc7ea95`](https://github.com/OZI-Project/OZI.build/commit/fc7ea9513a2ac2033afa5ed86ba267891b937b9f))

* docs: add homepage link — rjdbcm <rjdbcm@outlook.com>
([`ac65d38`](https://github.com/OZI-Project/OZI.build/commit/ac65d383eceb0870dcbde2b6ffbab965572aeb40))


### Features


* feat: use OZI for publishing

Feat/dogfood ozi
([`485bd37`](https://github.com/OZI-Project/OZI.build/commit/485bd37accff05383ca5ce509f5331129eb5baa7))


### Unknown


* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`f9de2ad`](https://github.com/OZI-Project/OZI.build/commit/f9de2ade260ef378098e7ad93e8491e9516717a0))

* Update pyproject.toml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`3060ee8`](https://github.com/OZI-Project/OZI.build/commit/3060ee81c23a5ba581a7cd4374bd074e6be71f79))

* remove unused imports — rjdbcm <rjdbcm@outlook.com>
([`831bcb1`](https://github.com/OZI-Project/OZI.build/commit/831bcb1763297b7b571b63033e205288c08fe4f6))

* Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`ce1842c`](https://github.com/OZI-Project/OZI.build/commit/ce1842cbe91a8f55c941d874cffde54e33984491))

* Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`cd75012`](https://github.com/OZI-Project/OZI.build/commit/cd75012f6ab5e5292dec6870aed7f6800d327d10))

## 1.8.3 (2024-12-23)


### Unknown


* 1.8.3 revert get_requires_for_build_wheel changes to match specification — rjdbcm <rjdbcm@outlook.com>
([`949398f`](https://github.com/OZI-Project/OZI.build/commit/949398f13d706480455e3b87d1a98a7f436eab59))

## 1.8.2 (2024-12-19)


### Unknown


* 1.8.2: correct license-expression format — rjdbcm <rjdbcm@outlook.com>
([`f15af89`](https://github.com/OZI-Project/OZI.build/commit/f15af89107b10669a4d1ba62fead05682946d46d))

* 1.8.2: more flexible license metadata expectations — rjdbcm <rjdbcm@outlook.com>
([`a4fbe70`](https://github.com/OZI-Project/OZI.build/commit/a4fbe70532d2ae79e5e637bf1cb4979fa544cfa1))

* Update .codeclimate.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`c286d3f`](https://github.com/OZI-Project/OZI.build/commit/c286d3fb7cf44730f6f101ae15c151bd31c0a803))

## 1.8.1 (2024-12-11)


### Unknown


* 1.8.1 use compatible version pins — rjdbcm <rjdbcm@outlook.com>
([`0014659`](https://github.com/OZI-Project/OZI.build/commit/0014659d9cbebf20d06648069fc6ee6c391864da))

## 1.8.0 (2024-12-09)


### Unknown


* 1.8.0: add regexploit — rjdbcm <rjdbcm@outlook.com>
([`5dea24f`](https://github.com/OZI-Project/OZI.build/commit/5dea24f212615e69a4f9c45f15b8b0d532ea39b9))

## 1.7.2 (2024-12-05)


### Unknown


* fix missing modules — rjdbcm <rjdbcm@outlook.com>
([`46fb19d`](https://github.com/OZI-Project/OZI.build/commit/46fb19db51fd7a31eaaece246a890dd27ceeaba6))

* refactor backend for future maintainability — rjdbcm <rjdbcm@outlook.com>
([`854cbb6`](https://github.com/OZI-Project/OZI.build/commit/854cbb6b08634f178fe6cc42e47b3dce42228208))

* refactor backend for future maintainability — rjdbcm <rjdbcm@outlook.com>
([`638359d`](https://github.com/OZI-Project/OZI.build/commit/638359d837a3b8c21c83f53859afd1bcb9832df1))

* refactor backend for future maintainability — rjdbcm <rjdbcm@outlook.com>
([`690d658`](https://github.com/OZI-Project/OZI.build/commit/690d6585ffdc76b8455537696e1a7d9d606797a6))

* refactor backend for future maintainability — rjdbcm <rjdbcm@outlook.com>
([`7cd9916`](https://github.com/OZI-Project/OZI.build/commit/7cd99160020f75a17c54b0600efb8e7c3c8e8fde))

* refactor backend for future maintainability — rjdbcm <rjdbcm@outlook.com>
([`3b5e3ae`](https://github.com/OZI-Project/OZI.build/commit/3b5e3ae6d0bf19d40023b93afe32402ae9b59427))

* refactor backend for future maintainability — rjdbcm <rjdbcm@outlook.com>
([`384b812`](https://github.com/OZI-Project/OZI.build/commit/384b812a7baac3eff81857cbc3967b541793f940))

* refactor backend for future maintainability — rjdbcm <rjdbcm@outlook.com>
([`e0cd258`](https://github.com/OZI-Project/OZI.build/commit/e0cd25818d51ed90182052b1b45cab1cd91eff3d))

## 1.7.1 (2024-12-02)


### Unknown


* fix wheel format
([`a346d98`](https://github.com/OZI-Project/OZI.build/commit/a346d98843527d9c0500c59d9faefaa11b7f88cd))

* fix wheel format
([`7caac3d`](https://github.com/OZI-Project/OZI.build/commit/7caac3da5b5a7a82b7f8c94e79af3acd73fa087d))

* fix wheel format — rjdbcm <rjdbcm@outlook.com>
([`482acd9`](https://github.com/OZI-Project/OZI.build/commit/482acd92ff2f5292c15e62cd0191845536312fc1))

## 1.7.0 (2024-12-02)


### Unknown


* update docs and bump to 1.7 — rjdbcm <rjdbcm@outlook.com>
([`74c857e`](https://github.com/OZI-Project/OZI.build/commit/74c857e835961eb3feb8cda559d5f84bb623e9e8))

* add pyc_wheel config — rjdbcm <rjdbcm@outlook.com>
([`49eba52`](https://github.com/OZI-Project/OZI.build/commit/49eba529dc792d0469d72b70a569b8ad47638f1b))

* update license info — rjdbcm <rjdbcm@outlook.com>
([`3f5de5d`](https://github.com/OZI-Project/OZI.build/commit/3f5de5d931cd0b36c93581d2417c952df0da3ed7))

* refactor module
([`717f2b7`](https://github.com/OZI-Project/OZI.build/commit/717f2b7278bbe8fcd5c5e75bca5ce3e7854c0d65))

* refactor module — rjdbcm <rjdbcm@outlook.com>
([`11c5db6`](https://github.com/OZI-Project/OZI.build/commit/11c5db6bd081889d0489884444cf2d41450bc4f8))

* Update .codeclimate.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`1bf1e24`](https://github.com/OZI-Project/OZI.build/commit/1bf1e2465902b6ab42c13313f9065ccea998a918))

* Create .codeclimate.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`44fc266`](https://github.com/OZI-Project/OZI.build/commit/44fc2669fe20f3805d984f73eac6bd8bb1887bc4))

* remove redundant code — rjdbcm <rjdbcm@outlook.com>
([`cea922b`](https://github.com/OZI-Project/OZI.build/commit/cea922be91e7fc18b30153046e6f3609aa84f672))

* refactor convert_wheel — rjdbcm <rjdbcm@outlook.com>
([`f1e6073`](https://github.com/OZI-Project/OZI.build/commit/f1e607322719541acc53c38b0faad2a3588e7beb))

## 1.6.1 (2024-10-27)


### Unknown


* OZI.build 1.6.1: revert metadata version 2.4
([`50bb16b`](https://github.com/OZI-Project/OZI.build/commit/50bb16b091cd372836d2e2fa8566672c5d8a1625))

* OZI.build 1.6.1: metadata version 2.4 — rjdbcm <rjdbcm@outlook.com>
([`e3bca2c`](https://github.com/OZI-Project/OZI.build/commit/e3bca2ce743db4147fec12672c0d2eeb28366fcd))

* OZI.build 1.6.1: license and license-expression mutually exclusive — rjdbcm <rjdbcm@outlook.com>
([`7079d40`](https://github.com/OZI-Project/OZI.build/commit/7079d40fec00ef89edac02584405a832fbc25598))

* Fall back to metadata version 2.2 waiting on PyPI — rjdbcm <rjdbcm@outlook.com>
([`d11223d`](https://github.com/OZI-Project/OZI.build/commit/d11223d520058d2a3f8476ed1299a5b69df207a2))

* OZI.build 1.6: support for Metadata-Version 2.4 — rjdbcm <rjdbcm@outlook.com>
([`503558d`](https://github.com/OZI-Project/OZI.build/commit/503558d7cd2a6e727a8dd6e13d6fae9473f2363e))

* OZI.build 1.6: support for Metadata-Version 2.4 — rjdbcm <rjdbcm@outlook.com>
([`b4ca34f`](https://github.com/OZI-Project/OZI.build/commit/b4ca34ffdc6e5a4fe7d94702532bca8de3174eda))

* Update scorecards.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`5237e01`](https://github.com/OZI-Project/OZI.build/commit/5237e010d39808b821ac64221bbed8068a3bc081))

* Update scorecards.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`2193fb3`](https://github.com/OZI-Project/OZI.build/commit/2193fb382145d2f729b4c899069ec149324b1d83))

* Create SECURITY.md — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`1565436`](https://github.com/OZI-Project/OZI.build/commit/156543655aac5696d06bc1d7d92ac974080f1c86))

* Create dependabot.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`a428f3a`](https://github.com/OZI-Project/OZI.build/commit/a428f3a7dbfa9be1517fa518e1954e28a21a14c5))

* OZI.build 1.5.2: pyc_wheel compilation now sensitive to ``python.bytecompile`` meson option setting — rjdbcm <rjdbcm@outlook.com>
([`d452bf1`](https://github.com/OZI-Project/OZI.build/commit/d452bf1a6abdd6b3ed5061ea045c467e9d81f3e0))

## 1.5.1 (2024-09-04)


### Unknown


* 1.5.1 docs updated — rjdbcm <rjdbcm@outlook.com>
([`077db2c`](https://github.com/OZI-Project/OZI.build/commit/077db2c34892f55ba67f5cd99d8be2ce22bb7cdd))

## 1.5.0 (2024-09-01)


### Unknown


* OZI.build 1.5.0 expect a valid license file path to copy to dist-info
([`b5679f5`](https://github.com/OZI-Project/OZI.build/commit/b5679f5e119a8b0b013f3cbe1f6640a9baf0c47f))

* OZI.build 1.5.0 expect a valid license file path to copy to dist-info
([`c454c12`](https://github.com/OZI-Project/OZI.build/commit/c454c1227518678358540c20b0fed72e59da3570))

* OZI.build 1.5.0 expect a valid license file path to copy to dist-info
([`c94c1f6`](https://github.com/OZI-Project/OZI.build/commit/c94c1f6eb70ca467fe1a26d426d9ba487a8aa7ce))

* OZI.build 1.5.0 expect a valid license file path to copy to dist-info
([`855f14d`](https://github.com/OZI-Project/OZI.build/commit/855f14db18d219bcd501e5facda8c41d4020626b))

* OZI.build 1.5.0 expect a valid license file path to copy to dist-info — rjdbcm <rjdbcm@outlook.com>
([`caf6c95`](https://github.com/OZI-Project/OZI.build/commit/caf6c9555710d064e80067b6d587f71b5a2e0803))

## 1.4.3 (2024-08-28)


### Unknown


* OZI.build 1.4.3 update docs — rjdbcm <rjdbcm@outlook.com>
([`3cc5e81`](https://github.com/OZI-Project/OZI.build/commit/3cc5e81ce513900de62a2df0dde827c09f484c30))

## 1.4.2 (2024-08-28)


### Unknown


* OZI.build 1.4.2 fix requires-python override from config — rjdbcm <rjdbcm@outlook.com>
([`3f2eff9`](https://github.com/OZI-Project/OZI.build/commit/3f2eff91bcda7b275ea6e35976eb8b7efc632e35))

## 1.4.1 (2024-08-28)


### Unknown


* OZI.build 1.4.1 loosen requires-python — rjdbcm <rjdbcm@outlook.com>
([`351e459`](https://github.com/OZI-Project/OZI.build/commit/351e45972fa546391178ab7943e37fc43058ba96))

## 1.4.0 (2024-08-28)


### Unknown


* OZI.build 1.4.0 add pure-python-abi key — rjdbcm <rjdbcm@outlook.com>
([`63c3409`](https://github.com/OZI-Project/OZI.build/commit/63c34091aa22d90372095a8c8c8d3d702b5808b8))

* OZI.build 1.4.0 add packaging requirement and flexible Requires-Python setting — rjdbcm <rjdbcm@outlook.com>
([`a6a9b5a`](https://github.com/OZI-Project/OZI.build/commit/a6a9b5aef61fbcb781f2b53149923d8e9faf0c18))

* OZI.build 1.4.0 add packaging requirement and flexible Requires-Python setting — rjdbcm <rjdbcm@outlook.com>
([`6200763`](https://github.com/OZI-Project/OZI.build/commit/620076353dcd9cd92906e12ea8de15ea1fbf3aae))

* OZI.build 1.3.4: set Requires-Python: >=3.10, <3.13 — rjdbcm <rjdbcm@outlook.com>
([`ee004f3`](https://github.com/OZI-Project/OZI.build/commit/ee004f3d44c8c9de108fdcd9e7956c8a9d474114))

* OZI.build 1.3.3 add keywords metadata schema — rjdbcm <rjdbcm@outlook.com>
([`72b7a14`](https://github.com/OZI-Project/OZI.build/commit/72b7a14d18777b0226299c425027dbe1238114da))

## 1.3.2 (2024-08-26)


### Unknown


* OZI.build 1.3.2 fix alternate download url — rjdbcm <rjdbcm@outlook.com>
([`49d0ec0`](https://github.com/OZI-Project/OZI.build/commit/49d0ec0bb8a9c39f8968f6c7fbd45cc1a8944df9))

## 1.3.1 (2024-08-26)


### Unknown


* OZI.build 1.3.1 remove duplicate schema keys
([`2dd8660`](https://github.com/OZI-Project/OZI.build/commit/2dd866068fdac7819133e5311e96575cb9da296c))

## 1.3.0 (2024-08-26)


### Bug fixes


* fix: warn for ignoring nested keys
([`1b6e088`](https://github.com/OZI-Project/OZI.build/commit/1b6e088a1fcd23191cd3f4ca23ac826426d4b65a))

* fix: warn for ignoring nested keys — rjdbcm <rjdbcm@outlook.com>
([`d7a8d7e`](https://github.com/OZI-Project/OZI.build/commit/d7a8d7e2740a6dd60ba5fcf401d36dc740312d93))

* fix: ``project.optional_dependencies`` is parsed into wheel METADATA — rjdbcm <rjdbcm@outlook.com>
([`6933ce8`](https://github.com/OZI-Project/OZI.build/commit/6933ce8397bffd293ad07ae9b4c95ce01da765a1))


### Unknown


* OZI.build 1.3.0

changes target the 1.20 release of OZI and spec version 0.9
add the remaining metadata keys and deprecate ``requires`` — rjdbcm <rjdbcm@outlook.com>
([`e22afcd`](https://github.com/OZI-Project/OZI.build/commit/e22afcdf257e9d3c5d2f3704ebdf93d87c2c66c9))

* OZI.build 1.3.0

changes target the 1.20 release of OZI and spec version 0.9
add the remaining metadata keys and deprecate ``requires`` — rjdbcm <rjdbcm@outlook.com>
([`de14c71`](https://github.com/OZI-Project/OZI.build/commit/de14c7125f58c049edf4475b38a4ecbc6399df08))

* Fix metadata to insert extras after Name — rjdbcm <rjdbcm@outlook.com>
([`db4f98b`](https://github.com/OZI-Project/OZI.build/commit/db4f98b62fb21d7607466e12606fcba40d9d5c5f))

* OZI.build 1.2.3 - fix length check for real — rjdbcm <rjdbcm@outlook.com>
([`14bb45c`](https://github.com/OZI-Project/OZI.build/commit/14bb45c507e8941772bb345f15d81356762171de))

* OZI.build 1.2.2 - fix length check — rjdbcm <rjdbcm@outlook.com>
([`57e6e3f`](https://github.com/OZI-Project/OZI.build/commit/57e6e3fdac5498f5868a8400360011b9f9abb823))

* OZI.build 1.2.1 - proper support for OZI optional_dependencies when PKG-INFO metadata is supplied — rjdbcm <rjdbcm@outlook.com>
([`7aaea14`](https://github.com/OZI-Project/OZI.build/commit/7aaea14a98fc00e0af66c09438d380be5a89985a))

* OZI.build 1.2.0 — rjdbcm <rjdbcm@outlook.com>
([`b9a14fa`](https://github.com/OZI-Project/OZI.build/commit/b9a14fa73238466eef13688654e29e64ae324cf4))

* clarify warnings on string value for optional_dependencies — rjdbcm <rjdbcm@outlook.com>
([`5430af7`](https://github.com/OZI-Project/OZI.build/commit/5430af774d9a90096f168ecea4c0cbd55dcdfda7))

* added _parse_project_optional_dependencies to config — rjdbcm <rjdbcm@outlook.com>
([`e6c29c1`](https://github.com/OZI-Project/OZI.build/commit/e6c29c1817068b2b2bde17455f6b297fea377e86))

* warn about string as nested key
([`dcd8e92`](https://github.com/OZI-Project/OZI.build/commit/dcd8e9249e6e807099a6f4f655dec9b186e505c4))

* allow nested optional_dependencies — rjdbcm <rjdbcm@outlook.com>
([`0802c75`](https://github.com/OZI-Project/OZI.build/commit/0802c752981e9e8d602f2306e6a45ee379db24f9))

* OZI.build 1.1 uses build-system requires from ``ozi-spec`` — rjdbcm <rjdbcm@outlook.com>
([`a68c9b0`](https://github.com/OZI-Project/OZI.build/commit/a68c9b0d6cb5db45eb8c3d23fceb2e64c814e73d))

## 1.0.2 (2024-08-10)


### Unknown


* 1.0.2 fix duplicate name key in PKG-INFO — rjdbcm <rjdbcm@outlook.com>
([`7568db5`](https://github.com/OZI-Project/OZI.build/commit/7568db517f9fdfc2bda02d694206b6fae9351687))

## 1.0.1 (2024-08-09)


### Unknown


* 1.0.1: fix RECORD rewriting — rjdbcm <rjdbcm@outlook.com>
([`5685288`](https://github.com/OZI-Project/OZI.build/commit/56852886465a3519fdf26f17948ebe438ca29399))

## 1.0.0 (2024-08-06)


### Unknown


* OZI.build 1.0.0 — rjdbcm <rjdbcm@outlook.com>
([`bcbd784`](https://github.com/OZI-Project/OZI.build/commit/bcbd784072453060db1869fccdc272aad0d05c6b))

* OZI.build 1.0.0 — rjdbcm <rjdbcm@outlook.com>
([`15cbc0d`](https://github.com/OZI-Project/OZI.build/commit/15cbc0d176398fb7ec401c6f8dec7b3ec33ab152))

* OZI.build 1.0.0 — rjdbcm <rjdbcm@outlook.com>
([`92a23ae`](https://github.com/OZI-Project/OZI.build/commit/92a23aeaf8a13d3d8d0ed9f01df7a567514056d7))

* 0.0.27: fix wheel abi tag setting — rjdbcm <rjdbcm@outlook.com>
([`69fa379`](https://github.com/OZI-Project/OZI.build/commit/69fa37912cf3103866a5f0e36b71fba13e58af85))

* 0.0.26: normalize dist-info
([`14fa596`](https://github.com/OZI-Project/OZI.build/commit/14fa5962435b6e3bf2875e461cc6c6616227c938))

* 0.0.25: renormalize wheel name only. — rjdbcm <rjdbcm@outlook.com>
([`bc08072`](https://github.com/OZI-Project/OZI.build/commit/bc080725d9b5230478c10962ea20c5f9a066f387))

* 0.0.24: revert normalize project name
([`ede285c`](https://github.com/OZI-Project/OZI.build/commit/ede285c20408edf873ebe318e41cdaeac3a11f8b))

* 0.0.23: normalize project name for dist-info
([`4a280bd`](https://github.com/OZI-Project/OZI.build/commit/4a280bda222dce0da311ea07f7416e46c119dc0c))

* 0.0.22: revert normalize project name for filenames
([`a47d8dd`](https://github.com/OZI-Project/OZI.build/commit/a47d8ddb86ade554c1761bc696f9b54714bc6344))

* 0.0.21: normalize project name for filenames
([`2810778`](https://github.com/OZI-Project/OZI.build/commit/28107783b70c42c3ea6e1ce0cf595278d2512d26))

* 0.0.21: normalize project name for filenames
([`0a4bbe9`](https://github.com/OZI-Project/OZI.build/commit/0a4bbe9126166441a5bd387de5254d571c68876a))

* 0.0.21: normalize project name for filenames
([`2cbbb69`](https://github.com/OZI-Project/OZI.build/commit/2cbbb69a19fd7ef51ba8a0347c05f5267030543d))

* 0.0.21: normalize project name for filenames
([`7c849e2`](https://github.com/OZI-Project/OZI.build/commit/7c849e26f715f29c8a439b1dbbc5af1c1050c8d7))

* 0.0.21: normalize project name for filenames
([`6f31361`](https://github.com/OZI-Project/OZI.build/commit/6f313614ecf5347fe610c05ef4a40eae6e9c8e2b))

* 0.0.21: normalize project name for filenames — rjdbcm <rjdbcm@outlook.com>
([`c948efd`](https://github.com/OZI-Project/OZI.build/commit/c948efdae79c57c87fa642725a68ccad3c5c127e))

* 0.2.0
([`fc3494e`](https://github.com/OZI-Project/OZI.build/commit/fc3494ec94effe4830fcf0239ee49d9848ab13aa))

* 0.0.19 update metadata
([`06d7855`](https://github.com/OZI-Project/OZI.build/commit/06d7855e10177c04eb2f714a63e3ee78c17e6e6c))

* 0.0.19 update metadata
([`a62840d`](https://github.com/OZI-Project/OZI.build/commit/a62840d7957345dd0221705c3e97dd46769c17ab))

## 0.0.18 (2024-05-11)


### Unknown


* [StepSecurity] Apply security best practices — StepSecurity Bot <bot@stepsecurity.io>
([`f17a780`](https://github.com/OZI-Project/OZI.build/commit/f17a7809e304ff947ca813d15263a4fee04e46b4))

* 0.0.18
([`b51793c`](https://github.com/OZI-Project/OZI.build/commit/b51793c55482c7fd8ec2a1c6b469758fbb6b9929))

* 0.0.18: fix typo in docs.
([`cb669f1`](https://github.com/OZI-Project/OZI.build/commit/cb669f1fa2a29c1aa7553dd99db7fcd8efe90503))

## 0.0.17 (2024-05-11)


### Unknown


* 0.0.17: updated release script.
([`a50e64c`](https://github.com/OZI-Project/OZI.build/commit/a50e64cdef65388aac3039f1487e83ab2e791d30))

* 0.0.17: updated release script.
([`e4d06e2`](https://github.com/OZI-Project/OZI.build/commit/e4d06e22157f826950069252c42f1b112bd37cca))

* 0.0.17: updated documentation.
([`1079842`](https://github.com/OZI-Project/OZI.build/commit/10798424278ef618a1610601598a5170f96f721b))

## 0.0.16 (2024-05-11)


### Unknown


* 0.0.16: summary key no longer required in metadata.
([`f128779`](https://github.com/OZI-Project/OZI.build/commit/f1287793ef8d1601aea966ac967e7d49f553e1b9))

## 0.0.15 (2024-05-04)


### Unknown


* 0.0.15: remove dependency on distutils.
([`ac60887`](https://github.com/OZI-Project/OZI.build/commit/ac60887b63c7618ab8b2a5f726b7d4074a4b6453))

## 0.0.14 (2024-05-04)


### Unknown


* vendor our pyc_wheel
([`910ea52`](https://github.com/OZI-Project/OZI.build/commit/910ea52e63bce6b310b59d5e13f2e5bd9b64f51d))

* vendor our pyc_wheel
([`4dc69ef`](https://github.com/OZI-Project/OZI.build/commit/4dc69ef6206af869733caa39cdfe5304be588128))

* vendor our pyc_wheel
([`982704c`](https://github.com/OZI-Project/OZI.build/commit/982704c2f1fd4d34dd13f76fcd3be35f54d6457e))

* vendor our pyc_wheel
([`0909c93`](https://github.com/OZI-Project/OZI.build/commit/0909c9363bceff6f291e2fcc31cede14f8fb044e))

* vendor our pyc_wheel
([`db8c821`](https://github.com/OZI-Project/OZI.build/commit/db8c821d56dbab056781bf31107e1eb0b0d35de6))

* vendor our pyc_wheel
([`5e67405`](https://github.com/OZI-Project/OZI.build/commit/5e67405c95f79a50184f33de69a0d4aaaa7a3e1e))

* vendor our pyc_wheel
([`56a8363`](https://github.com/OZI-Project/OZI.build/commit/56a8363b64acf3394f9b027991dfc95d9578d112))

* vendor our pyc_wheel
([`103c1be`](https://github.com/OZI-Project/OZI.build/commit/103c1be6714599ae3d11f85a66f336574b969f6a))

* vendor our pyc_wheel
([`0565f0c`](https://github.com/OZI-Project/OZI.build/commit/0565f0c808878abaf64a0b7cc47cd4adc8537806))

* vendor our pyc_wheel
([`6f95f07`](https://github.com/OZI-Project/OZI.build/commit/6f95f078e801597d3ff25f2a51d22ab8268cac86))

* vendor our pyc_wheel
([`8090351`](https://github.com/OZI-Project/OZI.build/commit/8090351f81cd53eb0a9e455de9ea61917b7b2370))

* vendor our pyc_wheel
([`e021209`](https://github.com/OZI-Project/OZI.build/commit/e0212092fecb3a58b1bd8fa93b2f7cee02dda88f))

* vendor our pyc_wheel
([`9a1564e`](https://github.com/OZI-Project/OZI.build/commit/9a1564e0f1938b1ed4fd53a21271ccc9834579dc))

* vendor our pyc_wheel
([`5fd54cc`](https://github.com/OZI-Project/OZI.build/commit/5fd54ccf0951fdd675fc6586ec5cc59c0708913a))

* vendor our pyc_wheel
([`bf6fe60`](https://github.com/OZI-Project/OZI.build/commit/bf6fe60cbee2186cdbb88650d302d2dad83f58cb))

* vendor our pyc_wheel
([`0ce0122`](https://github.com/OZI-Project/OZI.build/commit/0ce01223c47a655ea56e16f12b21d99606194015))

* vendor our pyc_wheel
([`fce333a`](https://github.com/OZI-Project/OZI.build/commit/fce333ad782e964f211ce2356bc4909df67b0354))

* vendor our pyc_wheel
([`1cec55d`](https://github.com/OZI-Project/OZI.build/commit/1cec55d86bca8419ba39fd0cb4c405254e232dd4))

* 0.0.13: fix for metadata generation in-situ
([`0a4dac4`](https://github.com/OZI-Project/OZI.build/commit/0a4dac406deaa40186a9b1624f4975dba38e8e96))

## 0.0.12 (2024-05-03)


### Unknown


* 0.0.12: fix for metadata generation in-situ
([`d584d72`](https://github.com/OZI-Project/OZI.build/commit/d584d72214a0e7c18c79172e454bed2d95ba6444))

* 0.0.12: fix for metadata generation in-situ
([`891c95d`](https://github.com/OZI-Project/OZI.build/commit/891c95dc2e3a6af1efc3eb3bb2f90ce1f9e4cc72))

* 0.0.12: fix for metadata generation in-situ
([`c748490`](https://github.com/OZI-Project/OZI.build/commit/c7484900225a46046892a7475025a402e357378a))

* 0.0.12: fix for metadata generation in-situ
([`d899606`](https://github.com/OZI-Project/OZI.build/commit/d899606ddc972b272dfa1a8c680bf6b83156bbb4))

## 0.0.11 (2024-05-03)


### Unknown


* 0.0.11: fix for metadata generation in-situ
([`b6b713d`](https://github.com/OZI-Project/OZI.build/commit/b6b713d0b1761bb9b3d1c28fc24255124ab7a965))

## 0.0.10 (2024-05-03)


### Unknown


* Update meson.build — Eden Rose, MSc <rjdbcm@outlook.com>
([`75b8956`](https://github.com/OZI-Project/OZI.build/commit/75b8956aab83d983600ce48e3b262f4db9b76fd5))

* Update buildapi.py - configure a builddir if one does not exist. — Eden Rose, MSc <rjdbcm@outlook.com>
([`ba83fcd`](https://github.com/OZI-Project/OZI.build/commit/ba83fcdc182acb9360ef7ea17a1193bfa3a35036))

* Update README.rst — Eden Rose, MSc <rjdbcm@outlook.com>
([`a7b7a67`](https://github.com/OZI-Project/OZI.build/commit/a7b7a67b92d2f170d7b37505947e71457ca36093))

* 0.0.9: fix OZI compiled wheel tagging.
([`9377d1d`](https://github.com/OZI-Project/OZI.build/commit/9377d1de1dd038e0636f10502bcc78a21499fbdd))

## 0.0.9 (2024-05-02)


### Unknown


* 0.0.9: fix OZI compiled wheel tagging.
([`b7f19e5`](https://github.com/OZI-Project/OZI.build/commit/b7f19e5be8d5d50cb721e6d15b07c92a5d96fe77))

* Update buildapi.py — Eden Rose, MSc <rjdbcm@outlook.com>
([`7693a8e`](https://github.com/OZI-Project/OZI.build/commit/7693a8e502f5c0765b63caa136b3a31149dc370f))

* 0.0.8
([`8ba7f0c`](https://github.com/OZI-Project/OZI.build/commit/8ba7f0cca250aff874ee3505c98fd35257d23db8))

* 0.0.8: fix PKG-INFO rendering in build wheel from sdist.
([`b1d93f7`](https://github.com/OZI-Project/OZI.build/commit/b1d93f7c0ac8afd35b5112499e4ad6ff4d628587))

* Update buildapi.py - fix for no argument ``python -m build`` — Eden Rose, MSc <rjdbcm@outlook.com>
([`44ee148`](https://github.com/OZI-Project/OZI.build/commit/44ee148a253fa29d88e1b4c848b71881afc6e410))

* 0.0.7: remove PKG-INFO rendering.
([`e96b2a7`](https://github.com/OZI-Project/OZI.build/commit/e96b2a7cce31ca86f02290e8bf380bf31bebda53))

* 0.0.7: remove PKG-INFO rendering.
([`7c7d4d7`](https://github.com/OZI-Project/OZI.build/commit/7c7d4d76ddddb145f1d613756f492c75d580c55e))

## 0.0.6 (2024-05-01)


### Unknown


* 0.0.6
([`39a2fa7`](https://github.com/OZI-Project/OZI.build/commit/39a2fa7945a6738687a7f16ec08d7a6456092eed))

* default to --no-tests in dist call.
([`c6b850d`](https://github.com/OZI-Project/OZI.build/commit/c6b850ddc50aeca2e8d881b1865a043a58fc7ee7))

## 0.0.5 (2024-05-01)


### Unknown


* 0.0.5
([`187b8f2`](https://github.com/OZI-Project/OZI.build/commit/187b8f2de4e0e5cda9ffe466b7527306e83c645d))

* meson-python-option-name works as described in docs
([`2507d8a`](https://github.com/OZI-Project/OZI.build/commit/2507d8a2eb10565cb60a3d925a0a8600371941a9))

## 0.0.4 (2024-05-01)


### Unknown


* 0.0.4
([`46e752b`](https://github.com/OZI-Project/OZI.build/commit/46e752b7d9be1644bcab267d73a8a34e32ddacce))

* optimize.
([`47a5dfb`](https://github.com/OZI-Project/OZI.build/commit/47a5dfbf5742c65ff6a61b3e57e81920b553520d))

* optimize.
([`a580659`](https://github.com/OZI-Project/OZI.build/commit/a580659a3d2914404d5398521eefd350f59a9490))

* run black.
([`85f0ed6`](https://github.com/OZI-Project/OZI.build/commit/85f0ed6f829641130939fc0d1fcb13b553dd6277))

* fix Debian incompatibility, always build with abi tag per OZI spec.
([`a2d63ee`](https://github.com/OZI-Project/OZI.build/commit/a2d63ee400c9768ee8e0c8e149bbf3c97935d8aa))

## 0.0.3 (2024-04-30)


### Unknown


* 0.0.3: add automatic detection of python dist version if requires-python is not set
([`88c2557`](https://github.com/OZI-Project/OZI.build/commit/88c25570baad2f86505bb76ea8df300fb079b039))

* clean up file lint
([`4bf8a09`](https://github.com/OZI-Project/OZI.build/commit/4bf8a09b5896d0cb80d520e7229c7343d7a033fa))

## 0.0.2 (2024-04-30)


### Continuous integration


* ci: Update to debian buster
([`cc0b0c0`](https://github.com/OZI-Project/OZI.build/commit/cc0b0c01163730aecd6fc938120789a343269460))


### Unknown


* fix wheel build on debian
([`33acef1`](https://github.com/OZI-Project/OZI.build/commit/33acef16d7e8a413e94f760c6d07b0dba87b7db6))

* fix wheel build on debian
([`ce339fa`](https://github.com/OZI-Project/OZI.build/commit/ce339faeed578f555dad3a32a99895eeebb9be38))

* bump
([`76078d7`](https://github.com/OZI-Project/OZI.build/commit/76078d7a8628463070f4d8a99a180182b6e234c5))

* dummy commit
([`cb7cedc`](https://github.com/OZI-Project/OZI.build/commit/cb7cedc1efeaa69b64ae9611e09174e7ccaa8059))

* bootstrap build
([`f934c7e`](https://github.com/OZI-Project/OZI.build/commit/f934c7ea8152ea58a7446dca862460f78404e90e))

* Pin requires.
([`a7fbd78`](https://github.com/OZI-Project/OZI.build/commit/a7fbd7820032a162cd36ab6fe0eb9060195a9b40))

* add fs import.
([`0f12de3`](https://github.com/OZI-Project/OZI.build/commit/0f12de38e1889a4443e7d150e2539b2229500c98))

* fix doc missed commit
([`f15de38`](https://github.com/OZI-Project/OZI.build/commit/f15de38d9c88accdf2afb4a872e127447013c4ff))

* also copyfile.
([`dcab9a8`](https://github.com/OZI-Project/OZI.build/commit/dcab9a8858dc9bc83568ad06655fb6f02aafabb5))

* fix typo
([`cbd5c7a`](https://github.com/OZI-Project/OZI.build/commit/cbd5c7a4eeb3c20abe0557fa18250ef94e15c5bd))

* Fix name.
([`f8a4b82`](https://github.com/OZI-Project/OZI.build/commit/f8a4b8228302e5c39d33bd746bf81d1131b5950b))

* bump version
([`42b28bc`](https://github.com/OZI-Project/OZI.build/commit/42b28bce4b97c4be6a3ec81ef13b6760faf03ee4))

* Fix maintainer-email
([`3ed30c2`](https://github.com/OZI-Project/OZI.build/commit/3ed30c21c8267e4cfe59d3e5f6c9b40a74f6b6d8))

* Update publishing metadata
([`a69f717`](https://github.com/OZI-Project/OZI.build/commit/a69f717ec4a46d869b412e56feddb7ba2f705634))

* Update to our own version.
([`3551ecc`](https://github.com/OZI-Project/OZI.build/commit/3551ecc79f4a3e3d7929e0843a2790ae60b5884e))

* Fix typo
([`4161065`](https://github.com/OZI-Project/OZI.build/commit/4161065b88b45200b00ccf59dd34a89543804982))

* Update buildapi.py - read pyproject as bytes. — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`91783e7`](https://github.com/OZI-Project/OZI.build/commit/91783e7709293155085fa38dcfe51b505686aee1))

* use toml.loads (load as string) — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`3bca7db`](https://github.com/OZI-Project/OZI.build/commit/3bca7db82062266a6c83aa40800db79cc6717373))

* Update buildapi.py - use tomllib or tomli — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`4410966`](https://github.com/OZI-Project/OZI.build/commit/4410966101ebad5a3bf03d4ea1b4f977cb073e8b))

* Update buildapi.py — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`30d3ab7`](https://github.com/OZI-Project/OZI.build/commit/30d3ab77309d7c3b86f8b227c2f9a33471de9617))

* Remove docs from build. — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`a14f3e6`](https://github.com/OZI-Project/OZI.build/commit/a14f3e686be3190d7adc75a9ff17c376bd2ffd81))

* Force rollback to 0.2
([`896b4ef`](https://github.com/OZI-Project/OZI.build/commit/896b4ef90c3cf80337ba7666908fd530bfb3f37a))

* Update buildapi.py — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`be5989c`](https://github.com/OZI-Project/OZI.build/commit/be5989cb36aa9aba43e160b8fa4db68f1bc06bba))

* Update buildapi.py — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`b84bafd`](https://github.com/OZI-Project/OZI.build/commit/b84bafd91b12e1ead13fe912ce7efa3504025af2))

* Update buildapi.py — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`69e45a4`](https://github.com/OZI-Project/OZI.build/commit/69e45a445ec78465bba8e92e66c02c8f9be07b3a))

* Update buildapi.py - use tomli — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`a74e33f`](https://github.com/OZI-Project/OZI.build/commit/a74e33ff0456481b46139995a3bc9d792a89fb20))

* Update meson.build — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`13996fc`](https://github.com/OZI-Project/OZI.build/commit/13996fc67b0a9ac12815cc21df95adf5ea32c3f4))

* Fix zip slip path traversal.
([`73acacf`](https://github.com/OZI-Project/OZI.build/commit/73acacf3877efd590f59d0dc1b9bdfa90ac1d92f))

* Update meson.build
([`386205a`](https://github.com/OZI-Project/OZI.build/commit/386205a57cc0125e7206bba4b9420f15173b5d62))

* Use same interpreter as mesonpep for build
([`fe3b008`](https://github.com/OZI-Project/OZI.build/commit/fe3b0086a11503d426500157ca8eb8b6822e1780))

* Use meson-python-option-name when calling meson
([`38964b2`](https://github.com/OZI-Project/OZI.build/commit/38964b2ec1cd2e5cb80cef2f10eea9102710c849))

* Fix get_platform usage
([`5bc2728`](https://github.com/OZI-Project/OZI.build/commit/5bc2728275a3e13767b771f3b61068d0e0b94744))

* Use packaging and wheel instead of pep425tags
([`a798c32`](https://github.com/OZI-Project/OZI.build/commit/a798c32d1a58466b166bb11f54c3b5bf96b581ee))

* Re add meson-options running meson configure

This broke during refactoring to make use of config_settings
([`aabe01e`](https://github.com/OZI-Project/OZI.build/commit/aabe01e993b87769860741b25d124f9c3fa0c8f2))

* Include subprojects in dist tarballs

Avoiding to redownload them when rebuilding
([`b1acebc`](https://github.com/OZI-Project/OZI.build/commit/b1acebc70b6d2e288c6b9ed76cefabd756490a47))

* Fix format of license field in pyproject.toml

PEP621 says that this must be a table with either a text field or a
license field.

Fixes https://gitlab.com/thiblahute/mesonpep517/-/issues/13
([`a11ee77`](https://github.com/OZI-Project/OZI.build/commit/a11ee772513071198d02d555ac26a3c32e10608f))

* Use requires-python differently to construct the wheel tag

PEP 621 and the mesonpep517 documentation specify that requires-python
takes a string of version specifiers denoting the python versions that
the source code is compatible with.  So we cannot use the string
provided by the user verbatim for the wheel tag (the Tag: field in the
WHEEL metadata and part of the wheel's filename).  It needs to be parsed
and processed first.

* Add packaging as a dependency so that we can parse the requirs-python
  version specifiers
* _write_wheel_file() changes:
  * Move creation of the Tag: field into the template.
  * Make getting and formatting the wheel tag the caller's
    responsibility (the caller can make use of the get_wheel_tag()
    which fixes the Tag: field being populated with information about
    the python which ran mesonpep517 instead of the python the user
    specified for building the wheel)
* Add NoPythonVersion exception which is thrown when the requires-python
  field eliminates all python versions (for instance `requires-python:
  >=3,<=2`)
* New function python_major_support(python_requirements):
  * Takes the string of python requirements specifiers (as given by the
    user in python-requires) and decides whether py2 and or py3 are
    supported.
  * this uses the packaging module to parse the specifiers and then
    loops through them, figuring out whether python2 and/or python3 are
    marked as compatible.  Caveats/cornercase behaviours of the present
    code:
    * If no python-requires is given, then the code returns that it is
      compatible with both python2 and python3.
    * If neither py2 or py3 are marked as compatible by what's specified
      in python-requires, then raises NoPythonVersion exception so the
      user can fix their python-requires line.
  * Log a warning when requires-python is specified using `py2` or `py3`.
    Version specifiers should be used instead.
* New function get_wheel_tag(config, is_pure):
  * This is a combination of code from _write_wheel_file() and
    WheelBuilder.build().
  * It constructs the complete wheel tag (python implementation (and
    implementation version), python abi, and platform.
  * Now handles pure python code that runs under both py2 and py3
    (`p2.py3`).
  * Note: Does not catch NoPythonVersion exception... Should we catch
    these and give the user an abbreviated error in this project or is
    a traceback good enough?
  * Wheel tag for compiled extensions are slightly better than before.
    Now, both the wheel tag and filename will use the python that we're
    building with for the implementation and abi fields.  Caveats:
    * Platform does not take into account manylinux.
    * Cross compilation (I think that meson itself supports cross
      compilation) is not accounted for in any of the tags.  The
      python for the cross compile target will likely not run locally so
      we'd have to do something completely different for that.
  * Log lack of meson-python-option-name at info or higher.  Previously
    it was logged as a warning but only for non-pure builds.
* prepare_metadata_for_build_wheel() and WheelBiuulder.biuld() now get
  the wheel tag via get_wheel_tag().  This way, the wheel tag will be
  the same in both the WHEEL file's Tag: field and in the wheel's filename.
* pyproject.toml:
  * Add packaging to the list of dependencies
  * change the requires-python: format to use a version specifier as
    specified in PEP-621
* Config.get_metadata():
  * Add Requires-Python to the distinfo/METADATA

This fixes the issues with `requires-python` from:
https://gitlab.com/thiblahute/mesonpep517/-/merge_requests/13

This addresses the transformation of requires-python as a specifier to a
wheel tag which was noted as a blocker on this MR:
https://gitlab.com/thiblahute/mesonpep517/-/merge_requests/10#note_634888717
([`0431b79`](https://github.com/OZI-Project/OZI.build/commit/0431b799d8e6d8d3201171edbd83a30f9fa60575))

* Add missing PEP 621 fields to schema.py
([`34e7261`](https://github.com/OZI-Project/OZI.build/commit/34e7261d8d544cf8ddc3b53a1dd126dec53156bf))

* doc: Move 'meson-options' documentation to the scheme
([`2d99046`](https://github.com/OZI-Project/OZI.build/commit/2d990468766f0e4241a2f3aa20ff89a40c7faf54))

* Port metadata format to pep621

https://www.python.org/dev/peps/pep-0621 standardizes the fields for the
metadata to be used by pep517 backend so we should use them.

This deprecates our own format for now but keeps working with them
warning about deprecations.

Fixes https://gitlab.com/thiblahute/mesonpep517/-/issues/8
([`c52fb7d`](https://github.com/OZI-Project/OZI.build/commit/c52fb7dbbc11704db8b6438236254410b6e4ca6b))

* Use build instead of pep517 for build frontend

Community is throwing support around build and is more maintained than
pep517.
([`beae30f`](https://github.com/OZI-Project/OZI.build/commit/beae30f838437380c4ab3881ad9b5976853899d1))

* Use config_settings given from PEP517 frontends

config_settings allow users to pass arbitrary settings to build
backends. In this case, we are doing a pass-through straight to Meson.
([`391d7f4`](https://github.com/OZI-Project/OZI.build/commit/391d7f4ee1204538f35cf774c6b0a61381ae4773))

* Fix get_abi tag
this was creating issue's like having a `\r` in abi tag and erroring out
on windows
([`b71281f`](https://github.com/OZI-Project/OZI.build/commit/b71281f0b0a9831293a17034ef575d78decb4294))

* Release 0.2
([`8b0c691`](https://github.com/OZI-Project/OZI.build/commit/8b0c6919166e11e21754a745f48e9c6f1381c0dc))

* Refer to PEP 639 in 'license' field description — Christopher Arndt <chris@chrisarndt.de>
([`3827f3f`](https://github.com/OZI-Project/OZI.build/commit/3827f3f5e80ae5306da7c977b4a5a319a24322fd))

* Add 'maintainer' and 'maintainer-email' metadata fields support — Christopher Arndt <chris@chrisarndt.de>
([`8ea55ae`](https://github.com/OZI-Project/OZI.build/commit/8ea55ae4b71f69afa55f3f7aa3728797b51c5e62))

* Add support for 'license' metadata field — Christopher Arndt <chris@chrisarndt.de>
([`f1bdc2d`](https://github.com/OZI-Project/OZI.build/commit/f1bdc2d84e0dcd91c2e05c8448fb3b7088b2f724))

* Fix writing Tag in WHEEL file in wheel — Christopher Arndt <chris@chrisarndt.de>
([`aba9da6`](https://github.com/OZI-Project/OZI.build/commit/aba9da6aad95288ac43322ffdc38afb84833b087))

* Metadata schema streamlining

* Sort schema dict by metadata field key
* Mark required metadata fields instead of optional ones — Christopher Arndt <chris@chrisarndt.de>
([`b1b6d2b`](https://github.com/OZI-Project/OZI.build/commit/b1b6d2bb6047cd04798bacaca3d1d6b8d12aef5e))

* Make readme mime-type detection a bit more robust — Christopher Arndt <chris@chrisarndt.de>
([`ef07375`](https://github.com/OZI-Project/OZI.build/commit/ef0737503d6fcd5d1400730a2c63671a1761bb84))

* Put needed parts of 'wheel.pep425tags' into new 'pep425tags' submodule

'wheel.pep425tags' is unavailable in 'wheel>=0.35'

* Include attribution and license from 'wheel' project.
* Include new 'pep425tags.py' file in meson build.

Fixes: #5 — Christopher Arndt <chris@chrisarndt.de>
([`13ac5db`](https://github.com/OZI-Project/OZI.build/commit/13ac5db2d47bfc51ad3989d9f7381255cb0720fa))

* Simplify METADATA writing

* Fix KeyError when optional 'home-page' metadata field not present.
* Write not-strictly-required fields to METADATA dynamically, instead
  of using fixed template string. — Christopher Arndt <chris@chrisarndt.de>
([`7b42504`](https://github.com/OZI-Project/OZI.build/commit/7b4250408954e75a69335a918f55a54b7c942393))

* Use meson to run the dist and install commands

Meson has wrappers around the dist and install targets. These are used
in favor of the backend-specific instructions in order to be agnsotic.
([`1cbba41`](https://github.com/OZI-Project/OZI.build/commit/1cbba41fbb224d374925c57cba75581bd78efd9c))

* Use 'backend-path' standard mechanism instead of intreehooks

Fixes https://gitlab.com/thiblahute/mesonpep517/-/issues/2
([`98fa4b6`](https://github.com/OZI-Project/OZI.build/commit/98fa4b6a9e6ec0467247421628c644a90b780ef0))

* Port from pytoml to `toml`

As per the pytoml github repo:

> The pytoml project is no longer being actively maintained. Consider using the toml package instead.
([`0358f05`](https://github.com/OZI-Project/OZI.build/commit/0358f05d6b99672e3be0696cb672a9c0bc5661f4))

* Add a COPYING file

And license as Apache 2.0 as meson so we can move the code there without licensing issue

Fixes https://gitlab.com/thiblahute/mesonpep517/-/issues/3
([`187f872`](https://github.com/OZI-Project/OZI.build/commit/187f8720ca004114160b6a27bba5d519d3be219f))

## 0.1.9999996 (2020-07-15)


### Unknown


* Release 0.1.9999996
([`1d3d091`](https://github.com/OZI-Project/OZI.build/commit/1d3d091cc8bdbfeb7deec4571ad840807f4adc38))

* Mark as depending on setuptools

Working around https://github.com/mesonbuild/meson/issues/7443
([`bb1a4ff`](https://github.com/OZI-Project/OZI.build/commit/bb1a4ff23101237d0d0f311716cf442782e044fb))

* Fix spelling issue
([`be3e2be`](https://github.com/OZI-Project/OZI.build/commit/be3e2beeaa75c595a015b2a6440d7e3bd9d213f8))

* Fix some spelling
([`d3ca51c`](https://github.com/OZI-Project/OZI.build/commit/d3ca51c80a7960b71b2f8852c235d9269cf2e038))

* Minor fix in the scheme
([`ec5c73c`](https://github.com/OZI-Project/OZI.build/commit/ec5c73c837842c19c18945404228ad079d3034d9))

* Handle some wheel version incompatibilities
([`c85cfe7`](https://github.com/OZI-Project/OZI.build/commit/c85cfe7f3b79f82d6368436836e1617039d22993))

* Validate scheme
([`9fc3947`](https://github.com/OZI-Project/OZI.build/commit/9fc394744c079b4b053b09ae17e14762ee396c4b))

* Auto generate documentation
([`ef3e4b6`](https://github.com/OZI-Project/OZI.build/commit/ef3e4b6c2ac5813980962ffbb0a5434380a95c0f))

* Factor a Config class
([`891fa59`](https://github.com/OZI-Project/OZI.build/commit/891fa59c53e536e3b199faf0178406ef577989c2))

* Enhance failures logs
([`83af376`](https://github.com/OZI-Project/OZI.build/commit/83af3767b82fef8f9e203bd7113f1e023e546ba7))

* Better handle missing hotdoc
([`40d0f96`](https://github.com/OZI-Project/OZI.build/commit/40d0f96b17e29ebe1bacefbfe9d48c79967d3c25))

* Allow passing a PKG-INFO file directly in a 'pkg-config-file' key
([`1d28406`](https://github.com/OZI-Project/OZI.build/commit/1d28406c30d373194365e8f19ce011c04e7fa41b))

* Fix build with py3.5
([`900a8cf`](https://github.com/OZI-Project/OZI.build/commit/900a8cf15807c5d0d8ac1c812286da581cdc5f44))

* Fix displaying project description
([`cfd23a3`](https://github.com/OZI-Project/OZI.build/commit/cfd23a3f13fbefbf0a68672179a9392dc1f5e7c3))

* Build the doc

And add CI
([`f9ba791`](https://github.com/OZI-Project/OZI.build/commit/f9ba791e8f6e183bfdf6999804021dc11faf98b8))

* Some cleanup
([`6f80206`](https://github.com/OZI-Project/OZI.build/commit/6f80206ba58821322e82d32ffeed1f55f10fdbcb))

* Remove metdatas in meson, it is not merged yet
([`00bb1b8`](https://github.com/OZI-Project/OZI.build/commit/00bb1b8ec8a977194dd897e30a332278cc957fe7))

* Properly name wheels
([`c7f027e`](https://github.com/OZI-Project/OZI.build/commit/c7f027ec50d24cfe53d97e09ddcce86e6bbf29ed))

* Add entry-points support
([`16d542f`](https://github.com/OZI-Project/OZI.build/commit/16d542f3b29758527f7a3ba625b547eaa475f3d8))

* Fix licensing

Using the same as meson to make a potential merge simpler
([`4ffdf43`](https://github.com/OZI-Project/OZI.build/commit/4ffdf432277859596e6cb8586b33b6887ca6c3d0))

* Enhance metadata file
([`4f6d8eb`](https://github.com/OZI-Project/OZI.build/commit/4f6d8eb51b191e6721b527ff544a63499898a060))

* Add a basic readme and a simple relese file
([`22824c8`](https://github.com/OZI-Project/OZI.build/commit/22824c8d1d046b84f570646054d241161d4ac3c9))

* Fix pypi build
([`b1bbe8e`](https://github.com/OZI-Project/OZI.build/commit/b1bbe8e9f1ec0d30622a4d764fbffc031a48c141))

* Initial commit
([`9c52e8e`](https://github.com/OZI-Project/OZI.build/commit/9c52e8e5f1452d635cc45d59693487f761ff465e))
